AQTLib, Asynchronous Quantitative Trading Library
=================================================

Requirements
------------

-  `Python`_ >=3.6
-  `IB-insync`_ (sync/async framework for Interactive Brokers API,
   tested to work with >=0.9.56)
-  A running `TWS`_ or `IB Gateway`_ application (version 972 or higher)

.. _Python: https://www.python.org
.. _IB-insync: https://github.com/erdewit/ib_insync
.. _TWS: https://www.interactivebrokers.com/en/index.php?f=15875
.. _IB Gateway: https://www.interactivebrokers.com/en/index.php?f=16457